
import { useState, useEffect } from 'react';
import { MapPin } from 'lucide-react';
import { 
  Select, 
  SelectContent, 
  SelectItem, 
  SelectTrigger, 
  SelectValue 
} from "@/components/ui/select";
import { Input } from "@/components/ui/input";
import { Label } from "@/components/ui/label";

interface GeographicInfoProps {
  formData: any;
  setFormData: (data: any) => void;
}

// Police stations mapped to residence areas
const policeStationsByArea: Record<string, string[]> = {
  dhaka_north: [
    'Adabor', 'Badda', 'Bhashantek', 'Cantonment', 'Darus Salam', 'Gulshan',
    'Hatirjheel', 'Khilkhet', 'Mirpur', 'Mohammadpur', 'Pallabi', 'Rampura',
    'Shah Ali', 'Sher-e-Bangla Nagar', 'Tejgaon', 'Uttara', 'Kafrul'
  ],
  dhaka_south: [
    'Bangsal', 'Chawkbazar', 'Dhanmondi', 'Hazaribagh', 'Jatrabari', 'Kadamtali',
    'Kalabagan', 'Kamrangirchar', 'Khilgaon', 'Kotwali', 'Lalbagh', 'Motijheel',
    'New Market', 'Paltan', 'Ramna', 'Shahbagh', 'Sutrapur', 'Wari'
  ],
  chittagong: [
    'Kotwali', 'Panchlaish', 'Chandgaon', 'Double Mooring', 'Pahartali',
    'Halishahar', 'Bakalia', 'Bayezid Bostami', 'Khulshi', 'EPZ', 'Karnaphuli'
  ],
  sylhet: [
    'Kotwali', 'Airport', 'Jalalabad', 'Shah Poran', 'South Surma', 'Moglabazar'
  ],
  rajshahi: [
    'Boalia', 'Motihar', 'Rajpara', 'Shah Makhdum'
  ],
  khulna: [
    'Kotwali', 'Sonadanga', 'Khalishpur', 'Khan Jahan Ali', 'Daulatpur'
  ],
  barisal: [
    'Kotwali', 'Airport', 'Kawnia', 'Bandar'
  ]
};

export const GeographicInfoSection = ({ formData, setFormData }: GeographicInfoProps) => {
  const [availablePoliceStations, setAvailablePoliceStations] = useState<string[]>([]);
  
  useEffect(() => {
    if (formData.residenceArea && policeStationsByArea[formData.residenceArea]) {
      setAvailablePoliceStations(policeStationsByArea[formData.residenceArea]);
      
      // If current police station is not in the new list, reset it
      if (formData.policeStation && !policeStationsByArea[formData.residenceArea].includes(formData.policeStation)) {
        setFormData(prev => ({ ...prev, policeStation: '' }));
      }
    } else {
      setAvailablePoliceStations([]);
    }
  }, [formData.residenceArea, setFormData]);

  const handleSelectChange = (name: string, value: string) => {
    setFormData(prev => ({ ...prev, [name]: value }));
  };

  return (
    <div className="glass-panel p-6 animate-fade-up" style={{ animationDelay: '0.2s' }}>
      <div className="flex items-center gap-2 mb-6">
        <div className="w-8 h-8 rounded-full bg-brand-blue/10 flex items-center justify-center">
          <MapPin className="w-4 h-4 text-brand-blue" />
        </div>
        <h3 className="font-semibold text-lg">Geographic Information</h3>
      </div>

      <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
        <div className="space-y-2">
          <Label htmlFor="residenceArea">Residence Area</Label>
          <Select 
            value={formData.residenceArea || ''} 
            onValueChange={(value) => handleSelectChange('residenceArea', value)}
          >
            <SelectTrigger className="input-field">
              <SelectValue placeholder="Select area" />
            </SelectTrigger>
            <SelectContent>
              <SelectItem value="dhaka_north">Dhaka North</SelectItem>
              <SelectItem value="dhaka_south">Dhaka South</SelectItem>
              <SelectItem value="chittagong">Chittagong</SelectItem>
              <SelectItem value="sylhet">Sylhet</SelectItem>
              <SelectItem value="rajshahi">Rajshahi</SelectItem>
              <SelectItem value="khulna">Khulna</SelectItem>
              <SelectItem value="barisal">Barisal</SelectItem>
            </SelectContent>
          </Select>
        </div>

        <div className="space-y-2">
          <Label htmlFor="policeStation">Police Station</Label>
          <Select 
            value={formData.policeStation || ''} 
            onValueChange={(value) => handleSelectChange('policeStation', value)}
            disabled={!formData.residenceArea || availablePoliceStations.length === 0}
          >
            <SelectTrigger className="input-field">
              <SelectValue placeholder={
                !formData.residenceArea 
                  ? "Select residence area first" 
                  : "Select police station"
              } />
            </SelectTrigger>
            <SelectContent>
              {availablePoliceStations.map((station) => (
                <SelectItem key={station} value={station}>{station}</SelectItem>
              ))}
            </SelectContent>
          </Select>
          {!formData.residenceArea && (
            <p className="text-xs text-muted-foreground mt-1">
              Please select a residence area first
            </p>
          )}
        </div>
      </div>
    </div>
  );
};
